@@ -2,7 +2,7 @@
 //
 // pgAdmin III - PostgreSQL Tools
 // RCS-ID:      $Id: ctlCodeWindow.cpp 6216 2007-04-19 11:28:08Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // ctlCodeWindow.cpp - debugger 
@@ -1085,7 +1085,7 @@ void ctlCodeWindow::displaySource(const wxString &packageOID, const wxString &fu
     }
 
     // Adjustment of the next position
-    if (current_line > 1) 
+    if (current_line >= 1) 
         current_line--;
 
     // Add the current-line indicator to the current line of code
@@ -1499,3 +1499,4 @@ wsCodeCache::wsCodeCache(const wxString &packageOID, const wxString &funcOID, co
 {
 }
 
+
