@@ -2,7 +2,7 @@
 //
 // pgAdmin III - PostgreSQL Tools
 // RCS-ID:      $Id: dbgPgConn.cpp 6213 2007-04-19 08:47:08Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dbgPgConn.cpp - debugger 
@@ -77,58 +77,126 @@ void dbgPgConn::Init( const wxString &server, const wxString &database, const wx
     	m_workerThread->Create();
     	m_workerThread->Run();
     }
+    
+    // Figure out the hostname/IP address
+    struct hostent *host;
+    unsigned long addr;
+    wxString hostip, hostname;
+
+#ifdef __WXMSW__
+    struct in_addr ipaddr;
+#else
+    unsigned long ipaddr;
+#endif
+    
+#ifndef __WXMSW__
+    if (!(server.IsEmpty() || server.StartsWith(wxT("/"))))
+    {
+#endif
+        addr = inet_addr(server.ToAscii());
+        if (addr == INADDR_NONE) // szServer is not an IP address
+        {
+            host = gethostbyname(server.ToAscii());
+            if (host == NULL)
+            {
+                wxLogError(__("Could not resolve hostname %s"), server.c_str());
+                return;
+            }
+
+        	memcpy(&(ipaddr),host->h_addr,host->h_length); 
+	    	hostip = wxString::FromAscii(inet_ntoa(*((struct in_addr*) host->h_addr_list[0])));
+            hostname = server;
+        }
+    	else
+        {
+    	    hostip = server;
+            hostname = server;
+        }
+#ifndef __WXMSW__
+    }
+    else
+        hostname = server;
+#endif
 
     // Build up a connection string
     wxString connectParams;
 
-    if( server.Length()) 
+    if(hostname.Length())
     {
-    	connectParams.Append( wxT( "host=" ));
-    	connectParams.Append( server );
+    	connectParams.Append(wxT( "host="));
+    	connectParams.Append(hostname);
 
-    	msg += delimiter + server; delimiter = _( ":" );
+    	msg += delimiter + server; delimiter = _(":");
+    }
+
+    if (hostip.Length()) 
+    {
+      connectParams.Append(wxT(" hostaddr="));
+      connectParams.Append(hostip);
     }
 
     if( port.Length()) 
     {
-    	connectParams += wxT( " port=" );
+    	connectParams += wxT(" port=");
     	connectParams += port;
 
-    	msg += delimiter + port; delimiter = _( ":" );
+    	msg += delimiter + port; delimiter = _(":");
     }
 
 
     if( database.Length()) 
     {
-    	connectParams.Append( wxT( " dbname=" ));
-    	connectParams.Append( database );
+    	connectParams.Append(wxT(" dbname="));
+    	connectParams.Append(qtConnString(database));
 
-    	msg += delimiter + database; delimiter = _( ":" );
+    	msg += delimiter + database; delimiter = _(":");
     }
 
-    if( username.Length()) 
+    if(username.Length())
     {
-    	connectParams.Append( wxT( " user=" ));
-    	connectParams.Append( username );
+    	connectParams.Append(wxT(" user="));
+    	connectParams.Append(username );
 
-    	msg += delimiter + username; delimiter =  _( ":" );
+    	msg += delimiter + username; delimiter =  _(":");
     }
 
-    if( password.Length()) 
+    if(password.Length()) 
     {
-    	connectParams.Append( wxT( " password=" ));
-    	connectParams.Append( password );
+    	connectParams.Append(wxT(" password="));
+    	connectParams.Append(password);
+    }
+
+    switch (sslmode)
+    {
+        case 1: 
+            connectParams.Append(wxT(" sslmode=require"));   
+            break;
+
+        case 2: 
+            connectParams.Append(wxT(" sslmode=prefer"));
+            break;
+
+        case 3: 
+            connectParams.Append(wxT(" sslmode=allow"));
+            break;
+
+        case 4: 
+            connectParams.Append(wxT(" sslmode=disable"));
+            break;
+
+        default:
+            break;
     }
 
     connectParams.Trim( true );
     connectParams.Trim( false );
 
-    m_frame->getStatusBar()->SetStatusText( wxString(_( "Connecting to " )) + msg, 1 );	
+    m_frame->getStatusBar()->SetStatusText( wxString(_( "Connecting to " )) + msg, 1 );
     m_pgConn = PQconnectdb( connectParams.ToAscii());
 
     if( PQstatus( m_pgConn ) == CONNECTION_OK )
     {
-    	m_frame->getStatusBar()->SetStatusText( wxString(_( "Connected to " )) + msg, 1 );	
+    	m_frame->getStatusBar()->SetStatusText( wxString(_( "Connected to " )) + msg, 1 );
 
     	PQsetClientEncoding( m_pgConn, "UNICODE" );
     }
@@ -286,7 +354,31 @@ bool dbgPgConn::BackendMinimumVersion(int major, int minor)
         wxString version=GetVersionString();
         sscanf(version.ToAscii(), "%*s %d.%d", &m_majorVersion, &m_minorVersion);
         m_isEdb = version.Upper().Matches(wxT("ENTERPRISEDB*"));
+
+        // EnterpriseDB 8.3 beta 1 & 2 and possibly later actually have PostgreSQL 8.2 style
+        // catalogs. This is expected to change either before GA, but in the meantime we
+        // need to check the catalogue version in more detail, and if we don't see what looks
+        // like a 8.3 catalog, force the version number back to 8.2. Yuck.
+        if (m_isEdb && m_majorVersion == 8 && m_minorVersion == 3)
+        {
+            PGresult *res;
+            wxString result;
+
+            res = waitForCommand(wxT( "SELECT count(*) FROM pg_attribute WHERE attname = 'proconfig' AND attrelid = 'pg_proc'::regclass"));
+
+            if (PQresultStatus(res) == PGRES_TUPLES_OK)
+            {
+                // Retrieve the query result and return it.
+                result=wxString(PQgetvalue(res, 0, 0), wxConvUTF8);
+
+                // Cleanup & exit
+                PQclear(res);
+            }
+            if (result == wxT("0"))
+                m_minorVersion = 2; 
+        }
     }
+
     return m_majorVersion > major || (m_majorVersion == major && m_minorVersion >= minor);
 }
 
