@@ -2,7 +2,7 @@
 //
 // pgAdmin III - PostgreSQL Tools
 // RCS-ID:      $Id: factory.cpp 6044 2007-03-12 20:38:50Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // debugger.cpp - Debugger factories
@@ -21,6 +21,7 @@
 #include "debugger/frmDebugger.h"
 #include "schema/pgFunction.h"
 #include "schema/pgTrigger.h"
+#include "schema/edbPackageFunction.h"
 
 ///////////////////////////////////////////////////
 // Debugger factory
@@ -32,12 +33,29 @@ debuggerFactory::debuggerFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *
 
 wxWindow *debuggerFactory::StartDialog(frmMain *form, pgObject *obj)
 {
+    // Check here to make sure the function still exists before proceeding.
+    // There is still a very small window in which it might be dropped, but
+    // that will be handled by a cache lookup failure error in the database
+    if (obj->GetConnection()->ExecuteScalar(wxT("SELECT count(*) FROM pg_proc WHERE oid = ") + NumToStr((long)obj->GetOid())) != wxT("1"))
+    {
+        wxLogError(_("The selected function could not be found."));
+        ctlTree *browser = form->GetBrowser();
+        wxTreeItemId item=browser->GetSelection();
+        if (obj == browser->GetObject(item))
+        {
+            pgCollection *coll=browser->GetParentCollection(obj->GetId());
+            browser->DeleteChildren(coll->GetId());
+            coll->ShowTreeDetail(browser);
+        }
+        return 0;
+    }
+
     // Setup the debugger frame
     frmDebugger *debugger = new frmDebugger(form, wxString::Format(_("Debugger - %s"), obj->GetFullIdentifier().c_str()));
 
     // Setup the connection properties to be used by the debugger
     dbgConnProp cp;
-    cp.m_database = obj->GetDatabase()->GetQuotedIdentifier();
+    cp.m_database = obj->GetDatabase()->GetIdentifier();
     cp.m_host = obj->GetServer()->GetName();
     cp.m_password = obj->GetDatabase()->GetServer()->GetPassword();
     cp.m_port = NumToStr((long)obj->GetServer()->GetPort());
@@ -50,7 +68,18 @@ wxWindow *debuggerFactory::StartDialog(frmMain *form, pgObject *obj)
 
     dbgBreakPointList &breakpoints = directDebugger->getBreakpointList();
     breakpoints.Append(new dbgBreakPoint(dbgBreakPoint::OID, NumToStr((long)obj->GetOid()), wxT("'NULL'")));
-    directDebugger->startDebugging();
+    if (!directDebugger->startDebugging())
+    {
+        ctlTree *browser = form->GetBrowser();
+        wxTreeItemId item=browser->GetSelection();
+        if (obj == browser->GetObject(item))
+        {
+            pgCollection *coll=browser->GetParentCollection(obj->GetId());
+            browser->DeleteChildren(coll->GetId());
+            coll->ShowTreeDetail(browser);
+        }
+        return 0;
+    }
 
     // Return the debugger window to frmMain.
     return debugger;
@@ -58,14 +87,25 @@ wxWindow *debuggerFactory::StartDialog(frmMain *form, pgObject *obj)
 
 bool debuggerFactory::CheckEnable(pgObject *obj)
 {
-    if (obj && !obj->IsCollection())
+    if (!obj)
+        return false;
+
+    // Can't debug catalog objects.
+    if (obj->GetSchema() && obj->GetSchema()->GetMetaType() == PGM_CATALOG)
+        return false;
+
+    // Must be a super user to create breakpoints of any kind.
+    if (!obj->GetServer() || !obj->GetServer()->GetSuperUser())
+        return false;
+
+    if (!obj->IsCollection())
     {
         switch (obj->GetMetaType())
         {
             case PGM_FUNCTION:
                 {
                     pgFunction *func = (pgFunction *)obj;
-                    if (func->GetReturnType() != wxT("trigger"))
+                    if (func->GetReturnType() != wxT("trigger") && func->GetReturnType() != wxT("\"trigger\""))
                     {
                         if (func->GetLanguage() == wxT("plpgsql") && obj->GetDatabase()->CanDebugPlpgsql())
                             return true;
@@ -80,7 +120,10 @@ bool debuggerFactory::CheckEnable(pgObject *obj)
                 break;
 
             case EDB_PACKAGEFUNCTION:
-                if (obj->GetDatabase()->GetConnection()->EdbMinimumVersion(8, 2) && obj->GetDatabase()->CanDebugEdbspl() && obj->GetName() != wxT("cons"))
+                if (obj->GetDatabase()->GetConnection()->EdbMinimumVersion(8, 2) && 
+                    obj->GetDatabase()->CanDebugEdbspl() && 
+                    obj->GetName() != wxT("cons") &&
+                    ((edbPackageFunction *)obj)->GetSource() != wxEmptyString)
                     return true;
                 break;
 
@@ -107,6 +150,24 @@ wxWindow *breakpointFactory::StartDialog(frmMain *form, pgObject *obj)
     else
         dbgOid = NumToStr((long)obj->GetOid());
 
+    // Check here to make sure the function still exists before proceeding.
+    // There is still a very small window in which it might be dropped, but
+    // we should be able to handle most cases here without having to do this 
+    // deep down in query threads.
+    if (obj->GetConnection()->ExecuteScalar(wxT("SELECT count(*) FROM pg_proc WHERE oid = ") + dbgOid) != wxT("1"))
+    {
+        wxLogError(_("The selected function could not be found."));
+        ctlTree *browser = form->GetBrowser();
+        wxTreeItemId item=browser->GetSelection();
+        if (obj == browser->GetObject(item))
+        {
+            pgCollection *coll=browser->GetParentCollection(obj->GetId());
+            browser->DeleteChildren(coll->GetId());
+            coll->ShowTreeDetail(browser);
+        }
+        return 0;
+    }
+
     // Setup the debugger frame
     frmDebugger *debugger = new frmDebugger(form, wxString::Format(_("Debugger - %s"), obj->GetFullIdentifier().c_str()));
     debugger->Show(true);
@@ -114,7 +175,7 @@ wxWindow *breakpointFactory::StartDialog(frmMain *form, pgObject *obj)
 
     // Setup the connection properties to be used by the debugger
     dbgConnProp cp;
-    cp.m_database = obj->GetDatabase()->GetQuotedIdentifier();
+    cp.m_database = obj->GetDatabase()->GetIdentifier();
     cp.m_host = obj->GetServer()->GetName();
     cp.m_password = obj->GetDatabase()->GetServer()->GetPassword();
     cp.m_port = NumToStr((long)obj->GetServer()->GetPort());
@@ -127,6 +188,7 @@ wxWindow *breakpointFactory::StartDialog(frmMain *form, pgObject *obj)
 
     dbgBreakPointList &breakpoints = globalDebugger->getBreakpointList();
     breakpoints.Append(new dbgBreakPoint(dbgBreakPoint::OID, dbgOid, wxT("'NULL'")));
+
     globalDebugger->startGlobalDebugging();
 
     // Return the debugger window to frmMain.
@@ -135,29 +197,38 @@ wxWindow *breakpointFactory::StartDialog(frmMain *form, pgObject *obj)
 
 bool breakpointFactory::CheckEnable(pgObject *obj)
 {
-    if (obj && !obj->IsCollection())
+    if (!obj)
+        return false;
+
+    // Can't debug catalog objects.
+    if (obj->GetSchema() && obj->GetSchema()->GetMetaType() == PGM_CATALOG)
+        return false;
+
+    // Must be a super user to create breakpoints of any kind.
+    if (!obj->GetServer() || !obj->GetServer()->GetSuperUser())
+        return false;
+
+    if (!obj->IsCollection())
     {
         switch (obj->GetMetaType())
         {
             case PGM_FUNCTION:
                 {
                     pgFunction *func = (pgFunction *)obj;
-                    if (func->GetReturnType() != wxT("trigger"))
-                    {
-                        if (func->GetLanguage() == wxT("plpgsql") && obj->GetDatabase()->CanDebugPlpgsql())
-                            return true;
-                        else if (func->GetLanguage() == wxT("edbspl") && obj->GetDatabase()->CanDebugEdbspl())
-                            return true;
-                        else
-                            return false;
-                    }
+                    if (func->GetLanguage() == wxT("plpgsql") && obj->GetDatabase()->CanDebugPlpgsql())
+                        return true;
+                    else if (func->GetLanguage() == wxT("edbspl") && obj->GetDatabase()->CanDebugEdbspl())
+                        return true;
                     else
                         return false;
                 }
                 break;
 
             case EDB_PACKAGEFUNCTION:
-                if (obj->GetDatabase()->GetConnection()->EdbMinimumVersion(8, 2) && obj->GetDatabase()->CanDebugEdbspl() && obj->GetName() != wxT("cons"))
+                if (obj->GetDatabase()->GetConnection()->EdbMinimumVersion(8, 2) && 
+                    obj->GetDatabase()->CanDebugEdbspl() && 
+                    obj->GetName() != wxT("cons") &&
+                    ((edbPackageFunction *)obj)->GetSource() != wxEmptyString)
                     return true;
                 break;
 
@@ -180,3 +251,6 @@ bool breakpointFactory::CheckEnable(pgObject *obj)
     return false;
 }
 
+
+
+
