@@ -2,7 +2,7 @@
 //
 // pgAdmin III - PostgreSQL Tools
 // RCS-ID:      $Id: dlgDirectDbg.cpp 6213 2007-04-19 08:47:08Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgDirectDbg.cpp - debugger 
@@ -125,7 +125,7 @@ void dlgDirectDbg::setupParamWindow( )
 //  you construct a dlgDirectDbg (obviously) when you're ready to display the
 //  prompt dialog to the user.
 
-void dlgDirectDbg::startDebugging( void )
+bool dlgDirectDbg::startDebugging( void )
 {
     // First, figure out what kind of target we are going to debug.
     // The caller filled in our m_breakpoint list with the name and
@@ -158,8 +158,11 @@ void dlgDirectDbg::startDebugging( void )
         }
     }
 
-    loadTargetInfo( m_target, m_connProp, targetType );
+    if (!loadTargetInfo( m_target, m_connProp, targetType ))
+        return false;
+
     populateParamGrid();
+    return true;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -173,7 +176,7 @@ void dlgDirectDbg::startDebugging( void )
 //  information required to connect to the server (like the hostname, port number,
 //  and user name).
 
-void dlgDirectDbg::loadTargetInfo( const wxString &target, const dbgConnProp & connProp, char targetType )
+bool dlgDirectDbg::loadTargetInfo( const wxString &target, const dbgConnProp & connProp, char targetType )
 {
     // Connect to the server using the connection properties contained in connProp
 
@@ -201,15 +204,17 @@ void dlgDirectDbg::loadTargetInfo( const wxString &target, const dbgConnProp & c
         {
             m_targetInfo = new dbgTargetInfo( target, m_conn, targetType );
         }
-        catch( std::runtime_error & e )
+        catch( const std::runtime_error & error )
         {
+            wxLogError(wxString(error.what(), wxConvUTF8));
             m_conn->Close();
-
-            throw( e );
+            return false;
         }
 
         this->SetTitle(m_targetInfo->getName());
     }
+
+    return true;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -429,12 +434,9 @@ bool dlgDirectDbg::activateDebugger( )
         // Populate the ArgInfo object's IN or INOUT variables only, OUT
         // variables will be assigned NULL later on.
 
-        if( arg.getMode() != wxT( "o" ))
+        if(arg.getMode() != wxT("o"))
         {
-            if( grdParams->GetCellValue( i, COL_VALUE ) == wxT( "" ))
-                arg.setValue( wxT( "NULL" ));
-            else
-                arg.setValue( grdParams->GetCellValue( i, COL_VALUE ));
+            arg.setValue( grdParams->GetCellValue(i, COL_VALUE));
             i++;
         }    
     }
@@ -587,7 +589,14 @@ void dlgDirectDbg::invokeTargetCallable()
             int len = arg.getValue().Length() + 1;
             char *tmp = new char[len];
             snprintf(tmp, len, "%s", (const char *)arg.getValue().mb_str(wxConvUTF8));
-            params->paramValues[i] = tmp;
+            if (strcmp(tmp, "") == 0)
+                params->paramValues[i] = 0;
+            else if (strcmp(tmp, "''") == 0)
+                params->paramValues[i] = "";
+            else if (strcmp(tmp, "\\'\\'") == 0)
+                params->paramValues[i] = "''";
+            else
+                params->paramValues[i] = tmp;
         }
         else // IN
         {
@@ -596,7 +605,14 @@ void dlgDirectDbg::invokeTargetCallable()
             int len = arg.getValue().Length() + 1;
             char *tmp = new char[len];
             snprintf(tmp, len, "%s", (const char *)arg.getValue().mb_str(wxConvUTF8));
-            params->paramValues[i] = tmp;
+            if (strcmp(tmp, "") == 0)
+                params->paramValues[i] = 0;
+            else if (strcmp(tmp, "''") == 0)
+                params->paramValues[i] = "";
+            else if (strcmp(tmp, "\\'\\'") == 0)
+                params->paramValues[i] = "''";
+            else
+                params->paramValues[i] = tmp;
         }
 
             if (i)
@@ -632,13 +648,13 @@ void dlgDirectDbg::invokeTargetStatement()
     // Now append the argument list
     query.Append(wxT("("));
 
-    for( int i = 0; i < m_targetInfo->getArgCount(); ++i )
+    for(int i = 0; i < m_targetInfo->getArgCount(); ++i)
     {
         wsArgInfo & arg = (*m_targetInfo)[i];
 
-        if( arg.getMode() == wxT("o"))
+        if(arg.getMode() == wxT("o"))
         {
-            if (!m_targetInfo->getIsFunction())
+            if (!m_targetInfo->getIsFunction() || m_targetInfo->getLanguage() == wxT("edbspl"))
                 query.Append( wxT("NULL::") + arg.getType() + wxT(", "));
         }
         else
