@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgFunction.cpp 6666 2007-09-25 15:25:12Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgFunction.cpp 7010 2008-01-23 09:55:56Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgFunction.cpp - PostgreSQL Function Property
@@ -640,13 +640,14 @@ wxString dlgFunction::GetSelectedDirection()
 wxString dlgFunction::GetArgs(const bool withNames, const bool inOnly)
 {
     wxString args;
+    bool isEdbspl = cbLanguage->GetValue() == wxT("edbspl");
  
     for (int i=0; i < lstArguments->GetItemCount(); i++)
     {
-        if (inOnly && lstArguments->GetText(i, 1) == wxT("OUT"))
+        if (!isEdbspl && inOnly && lstArguments->GetText(i, 1) == wxT("OUT"))
             continue;
 
-        if (i && !args.EndsWith(wxT(", ")))
+        if (i && !args.IsEmpty() && !args.EndsWith(wxT(", ")))
             args += wxT(", ");
 
         if (isProcedure)
@@ -654,15 +655,23 @@ wxString dlgFunction::GetArgs(const bool withNames, const bool inOnly)
             if (withNames && lstArguments->GetText(i, 2) != wxEmptyString)
                 args += qtIdent(lstArguments->GetText(i, 2)) + wxT(" ");
 
-            if (lstArguments->GetText(i, 1) != wxEmptyString)
-                args += lstArguments->GetText(i, 1) + wxT(" ");
+            // edbspl functions should list OUT params, but only by type.
+            if (!inOnly || !isEdbspl || lstArguments->GetText(i, 1) != wxT("OUT"))
+            {
+                if (lstArguments->GetText(i, 1) != wxEmptyString)
+                    args += lstArguments->GetText(i, 1) + wxT(" ");
+            }
                 
             args += lstArguments->GetText(i, 0);
         }
         else
         {
-            if (connection->BackendMinimumVersion(8, 1) && lstArguments->GetText(i, 1) != wxEmptyString)
-                args += lstArguments->GetText(i, 1) + wxT(" ");
+            // edbspl functions should list OUT params, but only by type.
+            if (!inOnly || !isEdbspl || lstArguments->GetText(i, 1) != wxT("OUT"))
+            {
+                if (connection->BackendMinimumVersion(8, 1) && lstArguments->GetText(i, 1) != wxEmptyString)
+                    args += lstArguments->GetText(i, 1) + wxT(" ");
+            }
 
             if (connection->BackendMinimumVersion(8, 0) && withNames && lstArguments->GetText(i, 2) != wxEmptyString)
                 args += qtIdent(lstArguments->GetText(i, 2)) + wxT(" ");
@@ -862,3 +871,4 @@ wxString dlgFunction::GetSql()
 }
 
 
+
