@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgPackage.cpp 6082 2007-03-16 12:58:18Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgPackage.cpp 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgPackage.cpp - EnterpriseDB package Property
@@ -86,9 +86,14 @@ int dlgPackage::Go(bool modal)
 
 pgObject *dlgPackage::CreateObject(pgCollection *collection)
 {
-    pgObject *obj=packageFactory.CreateObjects(collection, 0,
-         wxT(" WHERE pkgname = '") + GetName() + wxT("'")
-         wxT("\n   AND pkgnamespace=") + schema->GetOidStr());
+    pgObject *obj;
+    
+    if (collection->GetConnection()->EdbMinimumVersion(8, 2))
+        obj=packageFactory.CreateObjects(collection, 0,
+            wxT("   AND nspname = '") + GetName() + wxT("'"));
+    else
+        obj=packageFactory.CreateObjects(collection, 0,
+            wxT("   AND pkgname = '") + GetName() + wxT("'"));
 
     return obj;
 }
