@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgProperty.cpp 6719 2007-10-08 09:15:20Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgProperty.cpp 6976 2008-01-08 13:48:00Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgQuery.cpp - Property Dialog
@@ -147,14 +147,15 @@ wxString dlgProperty::GetHelpPage() const
         page=obj->GetHelpPage(false);
     else
     {
-        page=wxT("pg/sql-create");
-        page += wxString(factory->GetTypeName()).Lower();
+        // Attempt to get he page from the dialogue, otherwise, take a shot at it!
+        page=this->GetHelpPage(true);
+        if (page.Length() == 0)
+        {
+            page=wxT("pg/sql-create");
+            page += wxString(factory->GetTypeName()).Lower();
+        }
     }
-    
-    // There is no create column page...
-    if (page == wxT("pg/sql-createcolumn"))
-        page = wxT("pg/sql-createtable");
-
+			
     return page;
 }
 
@@ -317,7 +318,19 @@ void dlgProperty::CreateAdditionalPages()
 wxString dlgProperty::GetName()
 {
     if (txtName)
-        return txtName->GetValue().Strip(wxString::both);
+    {
+        if (GetObject())
+        {
+            // If there is an existing object name with a leading or trailing
+            // space, don't try to remove it.
+            if (GetObject()->GetName() == txtName->GetValue())
+                return txtName->GetValue();
+            else
+                return txtName->GetValue().Strip(wxString::both);
+        }
+        else
+            return txtName->GetValue().Strip(wxString::both);
+    }
     return wxEmptyString;
 }
 
@@ -431,7 +444,14 @@ void dlgProperty::FillCombobox(const wxString &query, ctlComboBoxFix *cb1, ctlCo
 
 void dlgProperty::AddUsers(ctlComboBoxFix *cb1, ctlComboBoxFix *cb2)
 {
-    FillCombobox(wxT("SELECT usename FROM pg_user ORDER BY usename"), cb1, cb2);
+    if (connection->BackendMinimumVersion(8, 1))
+    {
+        FillCombobox(wxT("SELECT rolname FROM pg_roles ORDER BY 1"), cb1, cb2);
+    }
+    else
+    {
+        FillCombobox(wxT("SELECT usename FROM pg_user ORDER BY 1"), cb1, cb2);
+    }
 }
 
 
@@ -1646,7 +1666,7 @@ wxWindow *dropCascadedFactory::StartDialog(frmMain *form, pgObject *obj)
 
 bool dropCascadedFactory::CheckEnable(pgObject *obj)
 {
-    return obj && obj->CanDropCascaded();
+    return obj && obj->CanDrop() && obj->CanDropCascaded();
 }
 
 
