@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgSynonym.cpp 6082 2007-03-16 12:58:18Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgSynonym.cpp 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgSynonym.cpp - EnterpriseDB Synonym Property
@@ -130,10 +130,12 @@ void dlgSynonym::ProcessTypeChange()
     if (cbTargetType->GetValue() != _("Public synonym"))
     {
         pgSet *schemas;
-        if (connection->BackendMinimumVersion(8, 1))
-            schemas = connection->ExecuteSet(wxT("SELECT nspname FROM pg_namespace WHERE nspname NOT LIKE E'pg\\_%' OR nspname = 'pg_catalog' ORDER BY nspname;"));
+        if (connection->BackendMinimumVersion(8, 2))
+            schemas = connection->ExecuteSet(wxT("SELECT nspname FROM pg_namespace WHERE nspparent = 0 AND nspname NOT LIKE E'pg\\_%' AND nspname NOT IN ('pg_catalog', 'sys', 'dbo', 'pgagent', 'information_schema') ORDER BY nspname;"));
+        else if (connection->BackendMinimumVersion(8, 1))
+            schemas = connection->ExecuteSet(wxT("SELECT nspname FROM pg_namespace WHERE nspname NOT LIKE E'pg\\_%' ORDER BY nspname;"));
         else
-            schemas = connection->ExecuteSet(wxT("SELECT nspname FROM pg_namespace WHERE nspname NOT LIKE 'pg\\_%' OR nspname = 'pg_catalog' ORDER BY nspname;"));
+            schemas = connection->ExecuteSet(wxT("SELECT nspname FROM pg_namespace WHERE nspname NOT LIKE 'pg\\_%' ORDER BY nspname;"));
 
         for (int x = 0; x < schemas->NumRows(); x++)
         {
