@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMain.cpp 6656 2007-09-21 19:38:10Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: frmMain.cpp 6936 2008-01-02 13:57:28Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmMain.cpp - The main form
@@ -471,16 +471,15 @@ void frmMain::Refresh(pgObject *data)
     
     if (newData != data)
     {
-        wxLogInfo(wxT("Deleting ") + data->GetTypeName() + wxT(" ") 
-            + data->GetQuotedFullIdentifier() + wxT(" for Refresh"));
+        wxLogInfo(wxT("Deleting %s %s for refresh"), data->GetTypeName().c_str(), data->GetQuotedFullIdentifier().c_str());
 
         if (data == currentObject)
             currentObject = newData;
 
         if (newData)
         {
-            wxLogInfo(wxT("Replacing with new Node ") + newData->GetTypeName() + wxT(" ") 
-                + newData->GetQuotedFullIdentifier() + wxT(" for Refresh"));
+            wxLogInfo(wxT("Replacing with new node %s %s for refresh"), newData->GetTypeName().c_str(), newData->GetQuotedFullIdentifier().c_str());
+
             newData->SetId(currentItem);    // not done automatically
             browser->SetItemData(currentItem, newData);
             delete data;
@@ -1138,11 +1137,7 @@ pgsqlHelpFactory::pgsqlHelpFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar
 
 wxWindow *pgsqlHelpFactory::StartDialog(frmMain *form, pgObject *obj)
 {
-    if (obj && obj->GetConnection() && obj->GetConnection()->GetIsEdb())
-        DisplayHelp(wxT("index"), HELP_ENTERPRISEDB);
-    else
-        DisplayHelp(wxT("index"), HELP_POSTGRESQL);
-
+    DisplayHelp(wxT("index"), HELP_POSTGRESQL);
     return 0;
 }
 
