@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmQuery.cpp 6681 2007-09-27 12:17:16Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: frmQuery.cpp 6986 2008-01-09 10:13:13Z hiroshi $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmQuery.cpp - SQL Query Box
@@ -609,7 +609,7 @@ void frmQuery::OnShowLineEnds(wxCommandEvent& event)
 
 void frmQuery::OnActivate(wxActivateEvent& event)
 {
-    if (event.GetActive() && !closing)
+    if (event.GetActive())
         updateMenu();
     event.Skip();
 }
@@ -1026,6 +1026,9 @@ void frmQuery::updateMenu(wxObject *obj)
     if (fp)
         return;
 
+    if (closing)
+		return;
+
     if (!obj || obj == sqlQuery)
     {
         canUndo=sqlQuery->CanUndo();
@@ -1223,8 +1226,7 @@ void frmQuery::OnChangeStc(wxStyledTextEvent& event)
 void frmQuery::OnPositionStc(wxStyledTextEvent& event)
 {
     wxString pos;
-    pos.Printf(_("Ln %d Col %d Ch %d"), sqlQuery->LineFromPosition(sqlQuery->GetCurrentPos()) + 1, sqlQuery->GetColumn(sqlQuery->GetCurrentPos()) + 1, 
-          sqlQuery->GetColumn(sqlQuery->GetCurrentPos()));
+    pos.Printf(_("Ln %d Col %d Ch %d"), sqlQuery->LineFromPosition(sqlQuery->GetCurrentPos()) + 1, sqlQuery->GetColumn(sqlQuery->GetCurrentPos()) + 1, sqlQuery->GetCurrentPos() + 1);
     SetStatusText(pos, STATUSPOS_POS);
 }
 
@@ -1287,7 +1289,8 @@ void frmQuery::OnSave(wxCommandEvent& event)
     wxUtfFile file(lastPath, wxFile::write, modeUnicode ? wxFONTENCODING_UTF8:wxFONTENCODING_DEFAULT);
     if (file.IsOpened())
      {
-        file.Write(sqlQuery->GetText());
+        if ((file.Write(sqlQuery->GetText()) == 0) && (!modeUnicode))
+            wxMessageBox(_("Query text incomplete.\nQuery contained characters that could not be converted to the local charset.\nPlease correct the data or try using UTF8 instead."));
         file.Close();
         changed=false;
         setExtendedTitle();
@@ -1409,7 +1412,7 @@ void frmQuery::OnSetEOLMode(wxCommandEvent& event)
 void frmQuery::OnSaveAs(wxCommandEvent& event)
 {
     wxFileDialog *dlg=new wxFileDialog(this, _("Save query file as"), lastDir, lastFilename, 
-        _("Query files (*.sql)|*.sql|UTF-8 query files (*.sql)|*.sql|All files (*.*)|*.*"), wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
+        _("Query files (*.sql)|*.sql|All files (*.*)|*.*"), wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
     if (dlg->ShowModal() == wxID_OK)
     {
         lastFilename=dlg->GetFilename();
@@ -1438,7 +1441,8 @@ void frmQuery::OnSaveAs(wxCommandEvent& event)
         wxUtfFile file(lastPath, wxFile::write, lastFileFormat ? wxFONTENCODING_UTF8:wxFONTENCODING_DEFAULT);
         if (file.IsOpened())
         {
-            file.Write(sqlQuery->GetText());
+            if ((file.Write(sqlQuery->GetText()) == 0) && (!lastFileFormat))
+                wxMessageBox(_("Query text incomplete.\nQuery contained characters that could not be converted to the local charset.\nPlease correct the data or try using UTF8 instead."));
             file.Close();
             changed=false;
             setExtendedTitle();
