@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgColumn.h 6281 2007-05-09 14:18:26Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgColumn.h 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgColumn.h PostgreSQL Column
@@ -90,10 +90,10 @@ public:
     bool GetSystemObject() const { return colNumber < 0; }
     wxString GetSql(ctlTree *browser);
 	wxString GetCommentSql();
-    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-createtable"); }
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-altertable"); }
 
     virtual bool CanDrop() { return inheritedCount == 0 && pgSchemaObject::CanDrop() && GetSchema()->GetMetaType() != PGM_CATALOG && GetTable()->GetMetaType() != PGM_VIEW; }
-    virtual bool CanCreate() { return GetTable()->GetMetaType() != PGM_VIEW; }
+    virtual bool CanCreate() { return GetTable()->GetMetaType() != PGM_VIEW && GetSchema()->GetMetaType() != PGM_CATALOG; }
     pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
     bool HasStats() { return true; }
