@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatabase.cpp 6738 2007-10-12 09:29:12Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgDatabase.cpp 7026 2008-01-31 13:53:02Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgDatabase.cpp - PostgreSQL Database
@@ -387,7 +387,7 @@ void pgDatabase::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *pr
             // Add child nodes if necessary
         if (browser->GetChildrenCount(GetId(), false) == 0)
         {
-            wxLogInfo(wxT("Adding child object to database ") + GetIdentifier());
+            wxLogInfo(wxT("Adding child object to database %s"), GetIdentifier().c_str());
 
 			if (settings->GetDisplayOption(_("Catalogs")))
 				browser->AppendCollection(this, catalogFactory);
