@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatatype.cpp 6142 2007-03-30 08:51:32Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgDatatype.cpp 6982 2008-01-08 15:19:03Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgDatatype.cpp - PostgreSQL Datatypes
@@ -160,9 +160,9 @@ DatatypeReader::DatatypeReader(pgDatabase *db, bool withDomains)
 {
     wxString condition=wxT("typisdefined AND typtype ");
     if (withDomains)
-        condition += wxT("IN ('b', 'c', 'd')");
+        condition += wxT("IN ('b', 'c', 'd', 'e')");
     else
-        condition += wxT("IN ('b', 'c')");
+        condition += wxT("IN ('b', 'c', 'e')");
 
     condition += wxT("AND typname NOT IN (SELECT relname FROM pg_class WHERE relnamespace = typnamespace AND relkind != 'c') ");
 
