@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.cpp 6714 2007-10-05 10:22:44Z guillaume $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgFunction.cpp 6984 2008-01-08 16:53:15Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgFunction.cpp - function class
@@ -132,7 +132,7 @@ wxString pgFunction::GetSql(ctlTree *browser)
             }
         }
 
-        if (!sql.EndsWith(wxT(";")))
+        if (!sql.Strip(wxString::both).EndsWith(wxT(";")))
             sql += wxT(";");
 
         size_t i;
@@ -304,7 +304,7 @@ wxString pgFunction::GetArgSigList()
 
     for (unsigned int i=0; i < argTypesArray.Count(); i++)
     {
-        // OUT parameters are not considered part of the signature
+        // OUT parameters are not considered part of the signature, except for EDB-SPL
         if (argModesArray.Item(i) != wxT("OUT"))
         {
             if (args.Length() > 0)
@@ -312,6 +312,16 @@ wxString pgFunction::GetArgSigList()
 
             args += argTypesArray.Item(i);
         }
+        else
+        {
+            if (GetLanguage() == wxT("edbspl"))
+            {
+                if (args.Length() > 0)
+                    args += wxT(", ");
+
+                args += argTypesArray.Item(i);
+            }
+        }
     }
     return args;
 }
@@ -341,11 +351,14 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
 
     typeMap map;
 
-    while(!types->Eof())
-    {
-        map[types->GetVal(wxT("oid"))] = types->GetVal(wxT("typname"));
-        types->MoveNext();
-    }
+	if (types)
+	{
+        while(!types->Eof())
+        {
+            map[types->GetVal(wxT("oid"))] = types->GetVal(wxT("typname"));
+            types->MoveNext();
+        }
+	}
 
     if (functions)
     {
@@ -409,13 +422,14 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
                 type = argTypesTkz.GetNextToken();
                 function->iAddArgType(map[type]);
 
-                // Now add the name, stripping the quotes if
+                // Now add the name, stripping the quotes and \" if
                 // necessary. 
                 name = argNamesTkz.GetNextToken();
                 if (!name.IsEmpty())
                 {
                     if (name[0] == '"')
                         name = name.Mid(1, name.Length()-2);
+                    name.Replace(wxT("\\\""), wxT("\""));
                     function->iAddArgName(name);
                 }
                 else
