@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgObject.cpp 6038 2007-03-12 13:19:27Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgObject.cpp 6992 2008-01-10 10:19:35Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgObject.cpp - PostgreSQL object base class
@@ -444,7 +444,8 @@ void pgObject::ShowTree(frmMain *form, ctlTree *browser, ctlListView *properties
         }
     }
 
-    wxLogInfo(wxT("Displaying properties for ") + GetTypeName() + wxT(" ")+GetIdentifier());
+    wxLogInfo(wxT("Displaying properties for %s %s"), GetTypeName().c_str(), GetIdentifier().c_str());
+
     if (form)
     {
         form->StartMsg(wxString::Format(_("Retrieving %s details"), GetTranslatedTypeName().c_str()));
@@ -870,6 +871,37 @@ void pgSchemaObject::UpdateSchema(ctlTree *browser, OID schemaOid)
                 return;
             }
         }
+
+        // If we get this far, it's possible the schema is actually a catalog
+        // in this case. We need to find the catalogs node and then search that.
+        pgObject *db=browser->GetObject(browser->GetItemParent(schemas->GetId()));
+        
+        wxASSERT(db);
+        treeObjectIterator catsIt(browser, db);
+        pgObject *catalogs;
+
+        while ((catalogs=(pgObject*)catsIt.GetNextObject()) != 0)
+        {
+            if (catalogs->GetMetaType() == PGM_CATALOG)
+                break;
+        }
+
+        // Assuming we got the catalogs node, now get the catalog
+        if (catalogs)
+        {
+            treeObjectIterator catIt(browser, catalogs);
+            pgCatalog *cat;
+
+            while ((cat=(pgCatalog*)catIt.GetNextObject()) != 0)
+            {
+                if (cat->GetOid() == schemaOid)
+                {
+                    SetSchema((pgSchema*)cat);
+                    return;
+                }
+            }
+        }
+
         wxMessageBox(_("The schema oid can't be located, please refresh all schemas!"), 
             _("Missing information"), wxICON_EXCLAMATION | wxOK, browser);
     }
