@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSchema.cpp 6558 2007-08-13 11:05:36Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgSchema.cpp 6936 2008-01-02 13:57:28Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgSchema.cpp - schema class
@@ -150,7 +150,7 @@ void pgSchemaBase::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *
         browser->RemoveDummyChild(this);
 
         // Log
-        wxLogInfo(wxT("Adding child object to schema ") + GetIdentifier());
+        wxLogInfo(wxT("Adding child object to schema %s"), GetIdentifier().c_str());
 
         if (!(GetMetaType() == PGM_CATALOG && (GetFullName() == wxT("dbo") || GetFullName() == wxT("sys") || GetFullName() == wxT("information_schema"))))
         {
@@ -283,13 +283,13 @@ pgObject *pgSchemaBaseFactory::CreateObjects(pgCollection *collection, ctlTree *
 	{
 		if (collection->GetDatabase()->BackendMinimumVersion(8, 1))
 		{
-			sql = wxT("SELECT CASE WHEN nspname LIKE E'pg\\_temp\\_%%' THEN 1\n")
-			      wxT("            WHEN (nspname LIKE E'pg\\_%') THEN 0\n");
+			sql = wxT("SELECT CASE WHEN nspname LIKE E'pg\\\\_temp\\\\_%%' THEN 1\n")
+			      wxT("            WHEN (nspname LIKE E'pg\\\\_%') THEN 0\n");
 		}
 		else
 		{
-			sql = wxT("SELECT CASE WHEN nspname LIKE 'pg\\_temp\\_%%' THEN 1\n")
-				  wxT("            WHEN (nspname LIKE 'pg\\_%') THEN 0\n");
+			sql = wxT("SELECT CASE WHEN nspname LIKE 'pg\\\\_temp\\\\_%%' THEN 1\n")
+				  wxT("            WHEN (nspname LIKE 'pg\\\\_%') THEN 0\n");
 		}
 		sql += wxT("            ELSE 3 END AS nsptyp,\n")
 			   wxT("       nsp.nspname, nsp.oid, pg_get_userbyid(nspowner) AS namespaceowner, nspacl, description,")
@@ -406,7 +406,17 @@ bool pgSchemaObjCollection::CanCreate()
 	if(IsCollectionForType(PGM_OPCLASS) || IsCollectionForType(PGM_OPFAMILY))
 		return false;
 
-    return GetSchema()->GetCreatePrivilege();
+    // TODO
+    // OK, this is a hack. Rules and Views are both derived from pgRuleObject, which
+    // is derived from pgSchemaObject. In order that they attached to the treeview 
+    // under the relevant node however, the Schema object is actually the table or
+    // View (yeah, I know - I didn't write it :-p ). This works fine *except* for
+    // Get CreatePrivilege() which doesn't exist in these classes so must be fixed
+    // up at this level. This needs a major rethink in the longer term
+    if (GetSchema()->GetMetaType() == PGM_TABLE || GetSchema()->GetMetaType() == PGM_VIEW)
+        return GetSchema()->GetSchema()->GetCreatePrivilege();
+    else
+        return GetSchema()->GetCreatePrivilege();
 }
 
 
