@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgServer.cpp 6687 2007-09-28 12:42:20Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgServer.cpp 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgServer.cpp - PostgreSQL Server
@@ -159,6 +159,9 @@ bool pgServer::Disconnect(frmMain *form)
         conn=0;
         connected=false;
         expandedKids=false;
+        ver = wxT("");
+        versionNum = wxT("");
+        lastSystemOID = 0;
     }
     UpdateIcon(form->GetBrowser());
     return true;
@@ -813,7 +816,12 @@ void pgServer::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prop
                     wxT(" WHERE relname='pga_job' AND nspname='pgagent'"));
 
                 if (!exists.IsNull())
-                    browser->AppendCollection(this, jobFactory);
+                {
+                    exists = conn->ExecuteScalar(wxT("SELECT has_schema_privilege('pgagent', 'USAGE')"));
+
+                    if (exists == wxT("t"))
+                        browser->AppendCollection(this, jobFactory);
+                }
             }
 
             if (conn->BackendMinimumVersion(8, 1))
