@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTable.cpp 6740 2007-10-12 14:34:30Z guillaume $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgTable.cpp 6936 2008-01-02 13:57:28Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgTable.cpp - Table class
@@ -509,8 +509,7 @@ void pgTable::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prope
         browser->RemoveDummyChild(this);
 
         // Log
-        wxLogInfo(wxT("Adding child object to table ") + GetIdentifier());
-
+        wxLogInfo(wxT("Adding child object to table %s"), GetIdentifier().c_str());
 
         browser->AppendCollection(this, columnFactory);
         browser->AppendCollection(this, constraintFactory);
