@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTrigger.cpp 6110 2007-03-20 10:26:28Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: pgTrigger.cpp 7012 2008-01-23 14:04:46Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgTrigger.cpp - Trigger class
@@ -101,7 +101,12 @@ wxString pgTrigger::GetSql(ctlTree *browser)
             + wxT("\n  FOR EACH ") + GetForEach();
         
         if (GetLanguage() == wxT("edbspl"))
-            sql += GetSource();
+        {
+            sql += wxT("\n") + GetSource();
+            if (!sql.Trim().EndsWith(wxT(";")))
+                sql = sql.Trim() + wxT(";");
+            sql += wxT("\n");
+        }
         else
         {
             sql += wxT("\n  EXECUTE PROCEDURE ") + triggerFunction->GetQuotedFullIdentifier() 
