@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: misc.cpp 6754 2007-10-18 08:46:09Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: misc.cpp 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // misc.cpp - Miscellaneous Utilities
@@ -395,7 +395,10 @@ wxString qtTypeIdent(const wxString& value)
     wxString result = value;
 
     if (needsQuoting(result, true))
+    {
+        result.Replace(wxT("\""), wxT("\"\""));
         return wxT("\"") + result + wxT("\"");
+    }
     else
         return result;
 }
@@ -409,7 +412,10 @@ wxString qtIdent(const wxString& value)
     wxString result = value;
 
     if (needsQuoting(result, false))
+    {
+        result.Replace(wxT("\""), wxT("\"\""));
         return wxT("\"") + result + wxT("\"");
+    }
     else
         return result;
 }
@@ -1003,6 +1009,25 @@ wxString ExecProcess(const wxString &cmd)
 	}
 	return res;
 }
+
+int ExecProcess(const wxString &command, wxArrayString &result)
+{
+    FILE *fp_command;
+    char buf[4098];
+
+    fp_command = popen(command.mb_str(wxConvUTF8), "r");
+
+    if (!fp_command)
+	    return -1;
+
+    while(!feof(fp_command))
+    {
+        if (fgets(buf, 4096, fp_command) != NULL)
+	        result.Add(wxString::FromAscii(buf));
+	}
+
+    return pclose(fp_command);
+}
 #endif
 
 #ifdef WIN32
@@ -1046,7 +1071,11 @@ bool pgAppMinimumVersion(const wxString &cmd, const int majorVer, const int mino
 {
 	wxArrayString output;
 
-	if (wxExecute(cmd + wxT(" --version"), output, 0) != 0)
+#ifdef __WXMSW__
+ 	if (wxExecute(cmd + wxT(" --version"), output, 0) != 0)
+#else
+	if (ExecProcess(cmd + wxT(" --version"), output) != 0)
+#endif
     {
         wxLogError(_("Failed to execute: %s --version"), cmd.c_str());
         return false;
@@ -1092,7 +1121,11 @@ bool isPgApp(const wxString &app)
 
 	wxArrayString output;
 
-	if (wxExecute(app + wxT(" --version"), output, 0) != 0)
+#ifdef __WXMSW__
+ 	if (wxExecute(app + wxT(" --version"), output, 0) != 0)
+#else
+	if (ExecProcess(app + wxT(" --version"), output) != 0)
+#endif
     {
         wxLogError(_("Failed to execute: %s --version"), app.c_str());
         return false;
@@ -1111,7 +1144,11 @@ bool isEdbApp(const wxString &app)
 
 	wxArrayString output;
 
-	if (wxExecute(app + wxT(" --version"), output, 0) != 0)
+#ifdef __WXMSW__
+ 	if (wxExecute(app + wxT(" --version"), output, 0) != 0)
+#else
+	if (ExecProcess(app + wxT(" --version"), output) != 0)
+#endif
     {
         wxLogError(_("Failed to execute: %s --version"), app.c_str());
         return false;
